@@ -78,7 +78,9 @@ void Diagram::UpdateDimensions()
 {
   size_t dayWidth=GetDayWidth();
 
-  hAdjustment->SetDimension(width,std::max(width,data.GetDaysCovered()*dayWidth));
+  hAdjustment->SetDimension(width,
+                            std::max(width,data.GetDaysCovered()*dayWidth)+
+                            valueUnitWidth);
   hAdjustment->SetStepSize(dayWidth);
 }
 
@@ -358,7 +360,10 @@ void Diagram::PrintHorizontalLabel(Lum::OS::DrawInfo* draw,
   std::wstring        tmp;
   Lum::Base::Calendar day;
 
-  draw->PushClip(this->x+weightUnitWidth,this->y,this->width-weightUnitWidth-valueUnitWidth,this->height);
+  draw->PushClip(this->x+weightUnitWidth,
+                 this->y,
+                 this->width-weightUnitWidth-valueUnitWidth,
+                 this->height);
   draw->PushFont(font);
   draw->PushForeground(labelColor);
 
@@ -434,7 +439,6 @@ void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw,
   }
 
   draw->PopForeground();
-
   draw->PopClip();
 }
 
@@ -571,7 +575,9 @@ void Diagram::GetDimension(size_t& width, size_t& height)
 {
   size_t dayWidth=GetDayWidth();
 
-  width=std::max(width,data.GetDaysCovered()*dayWidth);
+  width=std::max(width,
+                 data.GetDaysCovered()*dayWidth+
+                 valueUnitWidth);
 }
 
 void Diagram::Layout()
@@ -642,7 +648,8 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
     }
     return true;
   }
-  else if (event.IsGrabEnd() && event.button==Lum::OS::MouseEvent::button1) {
+  else if (event.IsGrabEnd() &&
+           event.button==Lum::OS::MouseEvent::button1) {
 
     if (std::abs(gestureStartX-event.x)>=std::abs(gestureStartY-event.y) ||
         std::abs(gestureStartY-event.y)<int((height*10)/100)) {
