@@ -17,15 +17,16 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Dialog.h>
+#include <Lum/Dlg/ActionDialog.h>
 
-class Statistics : public Lum::Dialog
+class Statistics : public Lum::Dlg::ActionDialog
 {
 public:
   Statistics();
   ~Statistics();
 
-  void PreInit();
+  Lum::Object* GetContent();
+  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
